@@ -1,7 +1,7 @@
 #!/bin/sh
 echo 'name: snap-core
-version: 0.9.2.2
-id: snap-core-0.9.2.2-74df8aee5648a9fe2906d831371ab2bc
+version: 0.9.4.0
+id: snap-core-0.9.4.0-aa42950ecf43ca25907a55a094e08299
 
 license: BSD3
 copyright:
@@ -50,43 +50,44 @@ hidden-modules: Snap.Internal.Instances
                 Snap.Internal.Types Snap.Internal.Test.RequestBuilder
                 Snap.Internal.Test.Assertions
 trusted: False
-import-dirs: /usr/local/lib/ghc/snap-core-0.9.2.2
-library-dirs: /usr/local/lib/ghc/snap-core-0.9.2.2
-hs-libraries: HSsnap-core-0.9.2.2
+import-dirs: /usr/local/lib/ghc/snap-core-0.9.4.0
+library-dirs: /usr/local/lib/ghc/snap-core-0.9.4.0
+hs-libraries: HSsnap-core-0.9.4.0
 extra-libraries:
 extra-ghci-libraries:
 include-dirs:
 includes:
-depends: HUnit-1.2.5.1-04fafbcfa793ac20134c5b9972485d17
-         MonadCatchIO-transformers-0.3.0.0-3d9f2598a492284fcb08e73b1981b4a4
-         attoparsec-0.10.1.0-3149dba69bd6a508e5a21c7e9cf969a8
-         attoparsec-enumerator-0.3-e16616615c93a4bab12cbaad5f63f76f
-         base-4.5.1.0-5b1c9d3d412ed227632edae6d2aca151
-         blaze-builder-0.2.1.4-cbacb369ecb80a55dd55bab68eb21ee1
-         blaze-builder-enumerator-0.2.0.4-084ae88fa2f45a7cf6c98461d286584d
-         bytestring-0.9.2.1-3c5b69d9d36e3a0179d120b97025ab86
-         bytestring-mmap-0.2.2-f43aedba6773dbccad28c4d79ae18979
-         case-insensitive-0.4.0.1-6ab4ff76a505da904c51cb94c3242e3c
-         containers-0.4.2.1-efa59805336a77490296ae3897cecb87
-         deepseq-1.3.0.0-c8a9e8b538aecb7581533b9c1d19faed
-         directory-1.1.0.2-4b2070a8941d5c76e41241a2ac457927
-         enumerator-0.4.19-54652fc37c21c9ff6bc4aced898d00e5
-         filepath-1.3.0.0-954c43b4f109cbd4121f1231c14d5cff
-         mtl-2.1.2-cf6082d8d4c6758d23401302efadd028
-         random-1.0.1.1-597e5fbb16214a2d52b559b0643d1749
-         regex-posix-0.95.2-d9fe86a76ffc5af4d3ed783956717b13
-         text-0.11.2.3-6d44323283fc0f3935743a72b4424942
-         time-1.4-b8e1c3d423daa1e2c5470a82caf23b52
-         unix-2.5.1.1-c23dadb7ccff9eeb5d1df0bd91909ca9
-         unix-compat-0.3.0.1-7c43122b26d2af8f349878266d10ac1d
-         unordered-containers-0.1.4.6-3501841bb7a7f313c99e53e7965a1a02
-         vector-0.10.0.1-fdf8e0c3f3c1cae1113ab97c34aa5c14
-         zlib-enum-0.2.2.1-f794f2612eaee96fd0337998dab8896a
+depends: HUnit-1.2.5.2-037d72e94f82e21ad0efc3a3ca13d5e2
+         MonadCatchIO-transformers-0.3.0.0-9df3c38f0408c0a91e2a32a7584ef9c9
+         attoparsec-0.10.4.0-fb379774679ae5734f1b536d33d902ec
+         attoparsec-enumerator-0.3.1-9799ee49c7c228079abd7930e5560145
+         base-4.6.0.1-185478ee9bcc4ae00bc1dbe06bac6937
+         blaze-builder-0.3.1.1-ac49b512143342e2370aead8ef93c70b
+         blaze-builder-enumerator-0.2.0.5-9ad1bc3197df6727c137d951b463129e
+         bytestring-0.10.0.2-fdb789c5db2e1ca48eb014403eee81b4
+         bytestring-mmap-0.2.2-ff6e08b3515cc82a6a1ab2ad8c28a870
+         case-insensitive-1.0.0.1-d2598685cbd81dd346ae8119d3bcded8
+         containers-0.5.0.0-3b8b869ec10d44736414ab5bea776319
+         deepseq-1.3.0.1-aa1be128186a233c7290faf88620ffe5
+         directory-1.2.0.1-5cea89dab5fade71d74e1fcf13ee5ca4
+         enumerator-0.4.19-af2193302e502a3821d2e5d25db7ea2c
+         filepath-1.3.0.1-edbc3d8247914b04f448e9261e7fe895
+         hashable-1.1.2.5-93ac9e8f4902e70447854e208345383a
+         mtl-2.1.2-735d9c92b4f214d454fb5168bb1eb6ee
+         random-1.0.1.1-de2c78bd5b6a198d2ecb982e7d11c02f
+         regex-posix-0.95.2-a34848eaff24ac32325260f99852c6c9
+         text-0.11.3.1-3fa3b4cb4ca4c0f49eeebe965c439ff9
+         time-1.4.0.1-11ddabfbdd9e1882a9135b100d37881b
+         unix-2.6.0.1-f31936082e1fa9175b93ddf28f79644c
+         unix-compat-0.4.1.1-7d1074b15de4b90d12292f611c87397a
+         unordered-containers-0.2.3.0-5bf92a1c1b90f6e2e5a5dbbd8a6ab013
+         vector-0.10.0.1-8398066fa66cdbff397fa1d47fe95cbe
+         zlib-enum-0.2.3-37dd2d636e8955ee1808dc2197600362
 hugs-options:
 cc-options:
 ld-options:
 framework-dirs:
 frameworks:
-haddock-interfaces: /usr/local/share/doc/hs-snap-core-0.9.2.2/html/snap-core.haddock
-haddock-html: /usr/local/share/doc/hs-snap-core-0.9.2.2/html
-' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
+haddock-interfaces: /usr/local/share/doc/hs-snap-core-0.9.4.0/html/snap-core.haddock
+haddock-html: /usr/local/share/doc/hs-snap-core-0.9.4.0/html
+' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
